<?php

namespace App\Http\Controllers\admin;

use App\Models\Car;
use App\Models\User;
use App\Models\Invoice;
use App\Models\Contract;
use App\Models\CarImage;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class AdminController extends Controller
{
    public function dashboard()
    {
        $stats = [
            'total_cars' => Car::count(),
            'active_contracts' => Contract::where('status', 'active')->count(),
            'pending_invoices' => Invoice::where('status', 'pending')->count(),
            'total_users' => User::where('role', 'user')->count(),
        ];

        $recent_contracts = Contract::with(['user', 'car'])
            ->orderBy('created_at', 'desc')
            ->take(5)
            ->get();

        $pending_invoices = Invoice::with(['user', 'contract'])
            ->where('status', 'pending')
            ->orderBy('due_date', 'asc')
            ->take(5)
            ->get();

        $totalUsers = User::where('role', 'user')->count();

        return view('admin.dashboard', compact('stats', 'recent_contracts', 'pending_invoices', 'totalUsers'));
    }

    public function login()
    {
        return view('admin.login');
    }

    public function postLogin(Request $request)
    {
        $credentials = $request->validate([
            'email' => 'required|email',
            'password' => 'required'
        ]);

        if (Auth::attempt($credentials)) {
            if (Auth::user()->role === 'admin') {
                return redirect()->route('admin.dashboard');
            }
            Auth::logout();
            return back()->with('error', 'Unauthorized access.');
        }

        return back()->withErrors([
            'email' => 'The provided credentials do not match our records.',
        ]);
    }

    public function logout()
    {
        Auth::logout();
        return redirect()->route('admin.login');
    }

    public function cars()
    {
        $cars = Car::with('images')->paginate();
        return view('admin.cars.index', compact('cars'));
    }

    public function contracts()
    {
        $contracts = Contract::with(['user', 'car'])->paginate();
        return view('admin.contracts.index', compact('contracts'));
    }

    public function invoices()
    {
        $invoices = Invoice::with(['user', 'contract'])->paginate();
        return view('admin.invoices.index', compact('invoices'));
    }

    

}
