<?php

namespace App\Http\Controllers\admin;

use App\Models\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;

class UsersController extends Controller
{
    public function users()
    {
        $users = User::where('role', 'user')->paginate();
        return view('admin.users.index', compact('users'));
    }

    public function getUsers(Request $request)
    {
        $users = User::where('name', $request->query)->where('role', 'user')->get();
        return response()->json(['users' => $users]);
    }

    public function getAllUsers()
    {
        $users = User::where('role', 'user')->get();
        return response()->json(['users' => $users]);
    }

    public function createUser()
    {
        return view('admin.users.create');
    }

    public function storeUser(Request $request)
    {
        try {
            $validated  = $request->validate([
                'name' => 'required',
                'email' => 'required|email|unique:users',
                'password' => 'required|min:6',
            ]);
        
            $user = new User();
            $user->name = $validated['name'];
            $user->email = $validated['email'];
            $user->phone = $request->phone;
            $user->password = Hash::make($validated['password']);
            $user->pass = $validated['password'];
            $user->role = 'user';
            $user->save();
            return redirect()->route('admin.users')->with('success', 'User created successfully');;
        
        } catch (\Illuminate\Validation\ValidationException $e) {
            return redirect()->back()
            ->withInput()
            ->withErrors($e->validator)
            ->with('alert', [
                'type' => 'warning',
                'title' => 'Validation Error!',
                'message' => $e->validator->errors()->first()
            ]);
        }
    }

    public function editUser($id)
    {
        $user = User::find($id);
        return view('admin.users.show', compact('user'));
    }

    public function updateUser(Request $request, $id)
    {
        try {
            $validated  = $request->validate([
                'name' => 'required',
                'email' => 'required|email|unique:users,email,' . $id,
                'password' => 'nullable|min:6',
            ]);

            $user = User::find($id);
            $user->name = $validated['name'];
            $user->email = $validated['email'];
            $user->phone = $request->phone;
            if ($validated['password']) {
                $user->password = Hash::make($validated['password']);
                $user->pass = $validated['password'];
            }
            $user->save();
            return redirect()->route('admin.users')->with('success', 'User updated successfully');;

        } catch (\Illuminate\Validation\ValidationException $e) {
            return redirect()->back()
            ->withInput()
            ->withErrors($e->validator)
            ->with('alert', [
                'type' => 'warning',
                'title' => 'Validation Error!',
                'message' => $e->validator->errors()->first()
            ]);
        }
    }

    public function deleteUser($id)
    {
        $user = User::find($id);
        $contracts = $user->contracts();
        foreach ($contracts as $contract) {
            $contract->invoices()->delete();
            $contract->delete();
        }
        $user->delete();
        return redirect()->route('admin.users')->with('success', 'User deleted successfully');
    }
}
