<?php

namespace App\Http\Controllers\front;

use Stripe\Stripe;
use App\Models\User;
use Stripe\Customer;
use App\Models\Invoice;
use Stripe\PaymentIntent;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;

class InvoiceController extends Controller
{
    public function invoices()
    {
        $invoices = Invoice::with(['user', 'contract'])->get();

        return view('front.user.invoices.index', compact('invoices'));
    }

    public function showInvoice($id)
    {
        $invoice = Invoice::with(['user', 'contract'])->findOrFail($id);

        return view('front.user.invoices.show', compact('invoice'));
    }

    public function showPublic($id, $token)
    {
        $invoice = Invoice::with(['user', 'contract'])->findOrFail($id);
        
        // Verify the token to ensure secure access
        if ($invoice->payment_token !== $token) {
            abort(403, 'Invalid access token');
        }

        return view('front.user.invoices.public-view', compact('invoice'));
    }

    public function confirmPayment(Request $request)
    {
        $invoice = Invoice::findOrFail($request->invoice_id);
        
        // Verify payment details from PayPal
        // Update invoice status
        $invoice->update([
            'status' => 'paid',
            'paid_at' => now(),
            'payment_method' => 'stripe',
            'payment_reference' => $request->payment_details['id']
        ]);

        // Retrieve the paymentIntent ID from the request
        $paymentIntentId = $request->input('payment_intent_id');
    
        try {
            Stripe::setApiKey(env('STRIPE_SECRET'));
    
            // Retrieve the PaymentIntent
            $paymentIntent = PaymentIntent::retrieve($paymentIntentId);
    
            if ($paymentIntent->status === 'succeeded') {
                // Save the order in your database
                $data = Session::get('order_data'); // Retrieve stored order data
                
                if($request->user_id)
                {
                    $user = User::find($request->user_id);
                    // Step 1: Create or retrieve the Stripe customer
                    if (!$user->stripe_customer_id) {
                        // If the user doesn't have a Stripe customer ID, create a new customer
                        $customer = \Stripe\Customer::create([
                            'email' => $data['email'],
                            'name' => $data['f_name'] . ' ' . $data['l_name'],
                        ]);
            
                        // Save the Stripe customer ID in the database for future use
                        $user->stripe_customer_id = $customer->id;
                        $user->save();
                    } else {
                        // If the customer already exists, retrieve them
                        $customer = \Stripe\Customer::retrieve($user->stripe_customer_id);
                    }
                    
                    if ($paymentIntent->payment_method) {
                        
                        $paymentMethod = \Stripe\PaymentMethod::retrieve($paymentIntent->payment_method);
                        
                        
                        // // Save the payment method to the user_payment_methods table
                        // DB::table('payments')->insert([
                        //     'user_id' => $user->id,
                        //     'stripe_payment_method_id' => $paymentMethod->id,
                        //     'card_brand' => $paymentMethod->card->brand,
                        //     'card_last_four' => $paymentMethod->card->last4,
                        //     'is_default' => false // You can modify this to set a default method
                        // ]);
        
                    }
                }
                
                return response()->json([
                    'success' => true,
                    'redirect_url' => route('invoice.thank-you', $invoice->id)
                ]);
            
            } else {
                return response()->json(['error' => 'Payment failed. Please try again.']);
            }
    
        } catch (\Exception $e) {
            return response()->json(['error' => $e->getMessage()]);
        }
    }
}
