<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Contract extends Model
{
    protected $fillable = [
        'user_id',
        'start_date',
        'end_date',
        'payment_plan',
        'daily_rate',
        'amount',
        'terms_conditions',
        'status'
    ];

    protected $casts = [
        'start_date' => 'date',
        'end_date' => 'date',
        'daily_rate' => 'decimal:2',
        'status' => 'string',
    ];

    // Relationships
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function car()
    {
        return $this->belongsTo(Car::class);
    }

    public function invoices()
    {
        return $this->hasMany(Invoice::class);
    }

    public function getTotalAmount()
    {
        $days = $this->start_date->diffInDays($this->end_date);
        return $days * $this->daily_rate;
    }

    public function isActive()
    {
        return $this->status === 'active';
    }
}
