<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Invoice extends Model
{
    protected $fillable = [
        'contract_id',
        'user_id',
        'invoice_date',
        'invoice_number',
        'due_date',
        'amount',
        'tax_amount',
        'payment_method',
        'payment_reference',
        'paid_at',
        'status'
    ];

    protected $dates = [
        'invoice_date',
        'due_date'
    ];

    const STATUSES = [
        'unpaid',
        'paid',
        'partially_paid',
        'overdue',
        'cancelled'
    ];

    protected static function boot()
    {
        parent::boot();

        static::saving(function ($invoice) {
            if (!in_array($invoice->status, self::STATUSES)) {
                throw new \InvalidArgumentException('Invalid status value');
            }
        });
    }

    // Relationships
    public function contract()
    {
        return $this->belongsTo(Contract::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function payments()
    {
        return $this->hasMany(Payment::class);
    }

    public function isPaid()
    {
        return $this->status === 'paid';
    }

    public function isOverdue()
    {
        return $this->status === 'overdue' || 
            ($this->status === 'pending' && $this->due_date->isPast());
    }
}
