@extends('admin.layouts.app')
@section('content')

<style>

a.theRemovingBtn {
    background: #000;
    padding: 16px 28px;
    color: #fff;
    font-size: 14px;
    border-radius: 7px;
}

.select2-container{
    width:30% !important;
}
</style>

<!-- main-panel -->
<div class="main-panel">
<div class="content-wrapper">
   <div class="row">
      <div class="col-12 col-md-12 grid-margin stretch-card">
         <div class="card">
            <div class="card-body">
                <form action="{{ route('admin.contract.update', $contract->id) }}" method="POST">
                    @csrf
                    @method('PUT')
                    
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>User</label>
                                <input type="text" class="form-control" value="{{ $contract->user->name }}" readonly>
                            </div>

                            <div class="form-group">
                                <label>Start Date</label>
                                <input type="date" name="start_date" class="form-control @error('start_date') is-invalid @enderror" 
                                    value="{{ Carbon\Carbon::parse($contract->start_date)->format('Y-m-d') }}">
                                @error('start_date')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                            <div class="form-group">
                                <label>End Date</label>
                                <input type="date" name="end_date" class="form-control @error('end_date') is-invalid @enderror" 
                                    value="{{ Carbon\Carbon::parse($contract->end_date)->format('Y-m-d') }}">
                                @error('end_date')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>

                        <div class="col-md-6">
                            <div class="form-group">
                                <label>Payment Plan</label>
                                <select name="payment_plan" class="form-control @error('payment_plan') is-invalid @enderror">
                                    <option value="weekly" {{ $contract->payment_plan === 'weekly' ? 'selected' : '' }}>Weekly</option>
                                    <option value="monthly" {{ $contract->payment_plan === 'monthly' ? 'selected' : '' }}>Monthly</option>
                                </select>
                                @error('payment_plan')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                            <div class="form-group">
                                <label>Daily Rate</label>
                                <input type="number" name="daily_rate" step="0.01" class="form-control @error('daily_rate') is-invalid @enderror" 
                                    value="{{ $contract->daily_rate }}">
                                @error('daily_rate')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>

                            <div class="form-group">
                                <label>Total Amount</label>
                                <input type="number" name="amount" step="0.01" class="form-control @error('amount') is-invalid @enderror" 
                                    value="{{ $contract->amount }}">
                                @error('amount')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                @enderror
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>Terms & Conditions</label>
                        <textarea name="terms_conditions" class="form-control @error('terms_conditions') is-invalid @enderror" 
                            rows="4">{{ $contract->terms_conditions }}</textarea>
                        @error('terms_conditions')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>

                    <div class="form-group">
                        <label>Status</label>
                        <select name="status" class="form-control @error('status') is-invalid @enderror">
                            <option value="active" {{ $contract->status === 'active' ? 'selected' : '' }}>Active</option>
                            <option value="inactive" {{ $contract->status === 'inactive' ? 'selected' : '' }}>Inactive</option>
                            <option value="expired" {{ $contract->status === 'expired' ? 'selected' : '' }}>Expired</option>
                        </select>
                        @error('status')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>

                    <button type="submit" class="btn btn-primary">Update Contract</button>
                    <a href="{{ route('admin.contract.show', $contract->id) }}" class="btn btn-secondary">Cancel</a>
                </form>
            </div>
         </div>
      </div>
   </div>
</div>

@endsection

@section('script')

<script>
    // Calculate total amount based on daily rate and date range
    document.addEventListener('DOMContentLoaded', function() {
        const startDateInput = document.querySelector('input[name="start_date"]');
        const endDateInput = document.querySelector('input[name="end_date"]');
        const dailyRateInput = document.querySelector('input[name="daily_rate"]');
        const totalAmountInput = document.querySelector('input[name="amount"]');

        function calculateTotal() {
            const startDate = new Date(startDateInput.value);
            const endDate = new Date(endDateInput.value);
            const dailyRate = parseFloat(dailyRateInput.value) || 0;

            if (startDate && endDate && dailyRate) {
                const diffTime = Math.abs(endDate - startDate);
                const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
                const total = diffDays * dailyRate;
                totalAmountInput.value = total.toFixed(2);
            }
        }

        startDateInput.addEventListener('change', calculateTotal);
        endDateInput.addEventListener('change', calculateTotal);
        dailyRateInput.addEventListener('input', calculateTotal);
    });
</script>

@endsection
