@extends('admin.layouts.app')
@section('content')

<div class="main-panel">
    <div class="content-wrapper">
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex justify-content-between align-items-center mb-4">
                            <h4 class="card-title">Contract Details</h4>
                            <div>
                                <a href="{{ route('admin.contract.edit', $contract->id) }}" class="btn btn-primary">Edit Contract</a>
                                <a href="{{ route('admin.contracts') }}" class="btn btn-secondary">Back to List</a>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <table class="table table-bordered">
                                    <tr>
                                        <th width="200">User</th>
                                        <td>{{ $contract->user->name }}</td>
                                    </tr>
                                    <tr>
                                        <th>Start Date</th>
                                        <td>{{ Carbon\Carbon::parse($contract->start_date)->format('M d, Y') }}</td>
                                    </tr>
                                    <tr>
                                        <th>End Date</th>
                                        <td>{{ Carbon\Carbon::parse($contract->end_date)->format('M d, Y') }}</td>
                                    </tr>
                                    <tr>
                                        <th>Payment Plan</th>
                                        <td>{{ ucfirst($contract->payment_plan) }}</td>
                                    </tr>
                                </table>
                            </div>
                            <div class="col-md-6">
                                <table class="table table-bordered">
                                    <tr>
                                        <th width="200">Daily Rate</th>
                                        <td>${{ number_format($contract->daily_rate, 2) }}</td>
                                    </tr>
                                    <tr>
                                        <th>Total Amount</th>
                                        <td>${{ number_format($contract->amount, 2) }}</td>
                                    </tr>
                                    <tr>
                                        <th>Status</th>
                                        <td>
                                            <span class="badge badge-{{ $contract->status === 'active' ? 'success' : ($contract->status === 'inactive' ? 'warning' : 'danger') }}">
                                                {{ ucfirst($contract->status) }}
                                            </span>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>Created At</th>
                                        <td>{{ $contract->created_at->format('M d, Y H:i A') }}</td>
                                    </tr>
                                </table>
                            </div>
                        </div>

                        @if($contract->terms_conditions)
                            <div class="mt-4">
                                <h5>Terms & Conditions</h5>
                                <div class="border p-3 rounded">
                                    {!! nl2br(e($contract->terms_conditions)) !!}
                                </div>
                            </div>
                        @endif

                        {{-- <!-- Invoices Due This Week -->
                        <div class="mt-4">
                            <h5>Invoices Due This Week</h5>
                            @if($dueThisWeek->count() > 0)
                                <div class="table-responsive">
                                    <table class="table table-bordered">
                                        <thead>
                                            <tr>
                                                <th>Invoice Number</th>
                                                <th>Amount</th>
                                                <th>Due Date</th>
                                                <th>Status</th>
                                                <th>Actions</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            @foreach($dueThisWeek as $invoice)
                                                <tr>
                                                    <td>{{ $invoice->invoice_number }}</td>
                                                    <td>${{ number_format($invoice->amount, 2) }}</td>
                                                    <td>{{ Carbon\Carbon::parse($invoice->due_date)->format('M d, Y') }}</td>
                                                    <td>
                                                        <span class="badge badge-{{ $invoice->status === 'pending' ? 'warning' : 'success' }}">
                                                            {{ ucfirst($invoice->status) }}
                                                        </span>
                                                    </td>
                                                    <td>
                                                        @if($invoice->status === 'pending')
                                                            <button class="btn btn-sm btn-success mark-as-paid" 
                                                                    data-invoice-id="{{ $invoice->id }}">
                                                                Mark as Paid
                                                            </button>
                                                        @endif
                                                    </td>
                                                </tr>
                                            @endforeach
                                        </tbody>
                                    </table>
                                </div>
                            @else
                                <p>No invoices due this week.</p>
                            @endif
                        </div> --}}

                        <!-- All Invoices -->
                        <div class="mt-4">
                            <h5>All Invoices</h5>
                            <div class="table-responsive">
                                <table class="table table-bordered">
                                    <thead>
                                        <tr>
                                            <th>Invoice Number</th>
                                            <th>Amount</th>
                                            <th>Due Date</th>
                                            <th>Status</th>
                                            <th>Actions</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach($contract->invoices as $invoice)
                                            <tr>
                                                <td>{{ $invoice->invoice_number }}</td>
                                                <td>${{ number_format($invoice->amount, 2) }}</td>
                                                <td>{{ Carbon\Carbon::parse($invoice->due_date)->format('M d, Y') }}</td>
                                                <td>
                                                    @if($invoice->status === 'paid')
                                                    <span class="badge badge-success">
                                                        {{ ucfirst($invoice->status) }}
                                                    </span>
                                                    @elseif($invoice->status === 'unpaid')
                                                    <span class="badge badge-warning">
                                                        {{ ucfirst($invoice->status) }}
                                                    </span>
                                                    @else
                                                    <span class="badge badge-danger">
                                                        {{ ucfirst($invoice->status) }}
                                                    </span>
                                                    @endif
                                                </td>
                                                <td>
                                                    {{-- @if($invoice->status === 'unpaid')
                                                        <button class="btn btn-sm btn-success mark-as-paid" 
                                                                data-invoice-id="{{ $invoice->id }}">
                                                            Mark as Paid
                                                        </button>
                                                    @endif --}}
                                                    <div class="d-flex align-items-center">
                                                        <a href="{{ route('admin.invoice.show',$invoice->id) }}" class="btn btn-primary btn-sm btn-icon-text mr-3">
                                                            Show
                                                            <i class="typcn typcn-eye btn-icon-append"></i>
                                                        </a>
                                                        {{-- <a href="{{ route('admin.invoice.edit',$invoice->id) }}" class="btn btn-success btn-sm btn-icon-text mr-3">
                                                            Edit
                                                            <i class="typcn typcn-edit btn-icon-append"></i>
                                                        </a> --}}
                                                        <a href="{{ route('admin.invoice.delete',$invoice->id) }}" class="btn btn-danger btn-sm btn-icon-text mr-3">
                                                            Delete
                                                            <i class="typcn typcn-delete-outline btn-icon-append"></i>
                                                        </a>
                                                        @if($invoice->email_sent == true)
                                                        <button disabled class="btn bg-primary text-light btn-sm btn-icon-text">
                                                            Invoice Sent
                                                            <i class="typcn typcn-location-arrow-outline"></i>
                                                        </button>
                                                        @else
                                                        <a href="{{ route('admin.invoice.send',$invoice->id) }}" class="btn btn-warning btn-sm btn-icon-text">
                                                            Send Invoice
                                                            <i class="typcn typcn-location-arrow-outline"></i>
                                                        </a>
                                                        @endif
                                                    </div>
                                                </td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection

@section('scripts')
<script>
    document.querySelectorAll('.mark-as-paid').forEach(button => {
        button.addEventListener('click', function() {
            const invoiceId = this.getAttribute('data-invoice-id');
            
            Swal.fire({
                title: 'Confirm Payment',
                text: "Are you sure you want to mark this invoice as paid?",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Yes, mark as paid'
            }).then((result) => {
                if (result.isConfirmed) {
                    fetch(`/admin/invoices/${invoiceId}/mark-paid`, {
                        method: 'POST',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}',
                            'Accept': 'application/json',
                            'Content-Type': 'application/json'
                        },
                    })
                    .then(response => response.json())
                    .then(data => {
                        if(data.success) {
                            Swal.fire(
                                'Marked as Paid!',
                                'The invoice has been marked as paid.',
                                'success'
                            ).then(() => {
                                window.location.reload();
                            });
                        }
                    })
                    .catch(error => {
                        Swal.fire(
                            'Error!',
                            'There was an error marking the invoice as paid.',
                            'error'
                        );
                    });
                }
            });
        });
    });
</script>
@endsection
