<!-- resources/views/invoices/public-view.blade.php -->
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Invoice #{{ $invoice->invoice_number }}</title>
    
    <!-- Include PayPal and Stripe SDKs -->
    <script src="https://www.paypal.com/sdk/js?client-id={{ env('PAYPAL_SANDBOX_CLIENT_ID') }}&currency=USD"></script>
    <script src="https://js.stripe.com/v3/"></script>
    
    <!-- Add your custom CSS here -->
    <style>
        .invoice-table {
            width: 100%;
            border-collapse: collapse;
        }
    
        .invoice-table,
        .invoice-table th,
        .invoice-table td {
            border: 1px solid #f2f2f2;
        }
    
        .invoice-table th,
        .invoice-table td {
            padding: 10px;
            text-align: left;
        }
    
        .invoice-table th {
            background-color: #f9f9f9;
        }
    
        .text-right {
            text-align: right;
        }
    </style>
</head>
<body>
    <div style="max-width: 800px; margin: auto; padding: 20px; background: #fff; box-shadow: 0px 0px 20px 5px gray;
    border-radius: 10px;">
        <table style="width: 100%; border-bottom: 2px solid #f2f2f2; margin-bottom: 20px;">
            <tr>
                <td style="text-align: left;">
                    <img src="{{ asset('build/assets/front/images/logo.png') }}" alt="Company Logo" style="max-width: 180px;">
                </td>
                <td style="text-align: right; font-size: 20px; color: #333;">
                    INVOICE
                </td>
            </tr>
        </table>

        <div class="d-flex">
            <div style="margin-bottom: 20px;">
                <h2 style="font-size: 18px; color: #333;">Invoice to</h2>
                <p>Name: {{ $invoice->contract->user->name }}<br>
                Email: {{ $invoice->contract->user->email }} <br>
                Phone: {{ $invoice->contract->user->phone }}</p>
            </div>
    
            <div style="margin-bottom: 20px; text-align: right;">
                <p><strong>Invoice ID :</strong> {{ $invoice->invoice_number }}<br>
                <strong>Date :</strong> <span>{{ $invoice->invoice_date }}</span></p>
            </div>
        </div>

        <table class="table table-striped text-center" style="width: 100%; border-bottom: 2px solid #f2f2f2; margin-bottom: 20px;">
            <thead>
                <tr>
                    <th scope="col">S.No</th>
                    <th scope="col"></th>
                    <th scope="col">car</th>
                    <th scope="col">model</th>
                    <th scope="col">Price Per Day</th>
                    <th scope="col">Status</th>
                    <th scope="col">Due Date</th>
                    
                    <th scope="col">total amount</th>
                </tr>
            </thead>

            <tbody>
                 
                <tr data-id="{{ $invoice->id }}">
                    <td>{{ $invoice->id }}</td>
                    <th scope="row"><img class="img-fluid" src="{{ asset('build/assets/admin/images/logo.png') }}" style="height: 55px; width: 75px; object-fit: cover;" alt=""></th>
                    
                    <td>car</td>
                    <td>model</td>
                    <td>$ {{ $invoice->contract->daily_rate  }}</td>
                    <td>{{ $invoice->status  }}</td>
                    <td>{{ $invoice->due_date  }}</td>
                    <td>$ {{ $invoice->amount }}</td>
                    
                </tr>
                
            </tbody>
        </table>

        <!-- Payment Options -->
        <div class="payment-options">
            <h3>Payment Methods</h3>
            <div class="form-group">
                <div class="payment-method-options">
                    <label>
                        <input type="radio" name="paymentMethod" value="PayPal" id="paypal-option">
                        <span>PayPal</span>
                        <img src="https://www.paypalobjects.com/webstatic/mktg/logo/pp_cc_mark_111x69.jpg" alt="PayPal">
                    </label>
                    <label>
                        <input type="radio" name="paymentMethod" value="Stripe" id="stripe-option">
                        <span>Credit Card</span>
                        <img src="https://img.icons8.com/color/48/000000/visa.png">
                        <img src="https://img.icons8.com/color/48/000000/mastercard.png">
                        <img src="https://img.icons8.com/color/48/000000/amex.png">
                    </label>
                </div>
            </div>

            <!-- PayPal Button -->
            <div id="paypal-button-container" style="display: none;"></div>

            <!-- Stripe Payment Form -->
            <form id="stripe-payment-form" style="display: none;">
                <div id="payment-element">
                    <!-- Stripe injects the Payment Element -->
                </div>
                <button id="btnSubmit" class="rounded" type="submit">Pay now</button>
            </form>
        </div>

        <p style="text-align: center; margin-top: 30px; font-size: 12px; color: #666;">Invoice was created on a computer and is valid without the signature and seal.</p>
    </div>
    

    {{-- <script>
        document.addEventListener('DOMContentLoaded', function () {
            var utcTimeElement = document.getElementById('utcTime');
            var utcTime = utcTimeElement.getAttribute('data-time');
            var localTime = new Date(utcTime).toLocaleString();  // Converts to local browser time
            
            utcTimeElement.textContent = localTime;  // Update the text content with local time
        });
    </script> --}}

<script src="https://js.stripe.com/v3/"></script>
<script>
    document.getElementById('payment-options').addEventListener('submit', async (e) => {
        e.preventDefault();
        const paymentMethod = document.getElementById('payment_method').value;

        if (paymentMethod === 'stripe') {
            const response = await fetch('{{ route('placeOrder') }}', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-TOKEN': '{{ csrf_token() }}',
                },
                body: JSON.stringify({
                    f_name: document.getElementById('f_name').value,
                    l_name: document.getElementById('l_name').value,
                    email: document.getElementById('email').value,
                    total_amount: document.getElementById('total_amount').value,
                    payment_method: 'stripe',
                }),
            });

            const data = await response.json();
            if (data.clientSecret) {
                const stripe = Stripe('{{ env('STRIPE_KEY') }}');
                const result = await stripe.confirmCardPayment(data.clientSecret);

                if (result.error) {
                    alert('Payment failed: ' + result.error.message);
                } else {
                    alert('Payment successful!');
                    window.location.href = data.redirect;
                }
            }
        }
    });
</script>

    
</body>
</html>
