@extends('front.user.layouts.app')
@section('title', 'Invoice #{{ $invoice->invoice_number }}')

@section('content')

    <!-- Include PayPal and Stripe SDKs -->
    <script src="https://www.paypal.com/sdk/js?client-id={{ env('PAYPAL_SANDBOX_CLIENT_ID') }}&currency=USD"></script>
    <script src="https://js.stripe.com/v3/"></script>

    <style>
        .invoice-table {
            width: 100%;
            border-collapse: collapse;
        }
    
        .invoice-table,
        .invoice-table th,
        .invoice-table td {
            border: 1px solid #f2f2f2;
        }
    
        .invoice-table th,
        .invoice-table td {
            padding: 10px;
            text-align: left;
        }
    
        .invoice-table th {
            background-color: #f9f9f9;
        }
    
        .text-right {
            text-align: right;
        }

        .invoice-container {
            max-width: 700px;
            margin: auto;
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
        }
        .invoice-container h2 {
            text-align: center;
            color: #333;
        }
        .payment-options {
            margin-top: 20px;
        }
        .payment-method-options label {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
            cursor: pointer;
        }
        .payment-method-options img {
            margin-left: 10px;
            height: 30px;
        }
        #paypal-button-container {
            margin-top: 20px;
        }
        #stripe-payment-form {
            margin-top: 20px;
        }
        .rounded {
            border-radius: 4px;
            padding: 10px 20px;
            background-color: #1976d2;
            color: white;
            border: none;
            cursor: pointer;
        }
        .rounded:hover {
            background-color: #0056b3;
        }
    </style>

    <section>
        <div class="container">
            <a class="btn btn-primary" href="{{ route('user.invoices.index') }}">Back</a>
        </div>
        <div style="max-width: 800px; margin: auto; padding: 20px; background: #fff; box-shadow: 0px 0px 20px 5px gray;
        border-radius: 10px;">
        <table style="width: 100%; border-bottom: 2px solid #f2f2f2; margin-bottom: 20px;">
            <tr>
                <td style="text-align: left;">
                    <img src="{{ asset('build/assets/front/images/logo.png') }}" alt="Company Logo" style="max-width: 180px;">
                </td>
                <td style="text-align: right; font-size: 20px; color: #333;">
                    INVOICE
                </td>
            </tr>
        </table>

        <div class="d-flex">
            <div style="margin-bottom: 20px;">
                <h2 style="font-size: 18px;color: #333;font-weight: 800;">Invoice to</h2>
                <p>Name: {{ $invoice->contract->user->name }}<br>
                Email: {{ $invoice->contract->user->email }} <br>
                Phone: {{ $invoice->contract->user->phone }}</p>
            </div>
    
            <div style="margin-bottom: 20px; text-align: right; margin-left: auto;">
                <p><strong>Invoice ID :</strong> {{ $invoice->invoice_number }}<br>
                <strong>Date :</strong> <span>{{ $invoice->invoice_date }}</span></p>
            </div>
        </div>

        <table class="table table-striped text-center" style="width: 100%; border-bottom: 2px solid #f2f2f2; margin-bottom: 20px;">
            <thead>
                <tr>
                    <th scope="col">S.No</th>
                    <th scope="col"></th>
                    <th scope="col">Car</th>
                    <th scope="col">Model</th>
                    <th scope="col">Price Per Day</th>
                    <th scope="col">Status</th>
                    <th scope="col">Due Date</th>
                    
                    <th scope="col">Total Amount</th>
                </tr>
            </thead>

            <tbody>
                 
                <tr data-id="{{ $invoice->id }}">
                    <td>{{ $invoice->id }}</td>
                    <th scope="row"><img class="img-fluid" src="{{ asset('build/assets/admin/images/logo.png') }}" style="height: 55px; width: 75px; object-fit: cover;" alt=""></th>
                    
                    <td>car</td>
                    <td>model</td>
                    <td>$ {{ $invoice->contract->daily_rate  }}</td>
                    <td>
                        @if($invoice->status === 'paid')
                        <span class="badge bg-success">
                            {{ ucfirst($invoice->status) }}
                        </span>
                        @elseif($invoice->status === 'unpaid')
                        <span class="badge bg-warning">
                            {{ ucfirst($invoice->status) }}
                        </span>
                        @else
                        <span class="badge bg-danger">
                            {{ ucfirst($invoice->status) }}
                        </span>
                        @endif
                    </td>
                    <td>{{ $invoice->due_date  }}</td>
                    <td>$ {{ $invoice->amount }}</td>
                    
                </tr>
                
            </tbody>
        </table>
        @if($invoice->status == 'paid')

        @else
        <div class="pay-now-btn">
            
            <form action="{{ route('user.paymentPage', $invoice->id) }}" method="get">
                @csrf
                <input type="hidden" name="user_id" id="" value="{{ auth()->user()->id }}">
                <input type="hidden" name="amount" id="" value="{{ $invoice->amount }}">
                <button id="btnSubmit" class="rounded float-end" type="submit">Pay now</button>
            </form>
            
        </div>
        @endif

        <p style="text-align: center; margin-top: 30px; font-size: 12px; color: #666;">Invoice was created on a computer and is valid without the signature and seal.</p>
    </div>
    </section>
    
{{-- 
    <script>
        const stripeOption = document.getElementById('stripe-option');
        const paypalOption = document.getElementById('paypal-option');
        const stripePaymentForm = document.getElementById('stripe-payment-form');
        const paypalButtonContainer = document.getElementById('paypal-button-container');

        // Stripe Integration
        const stripe = Stripe('{{ env('STRIPE_KEY') }}');
        let elements = stripe.elements();
        let paymentElement = elements.create('payment');
        
        stripeOption.addEventListener('change', function () {
            if (stripeOption.checked) {
                stripePaymentForm.style.display = 'block';
                paypalButtonContainer.style.display = 'none';
                paymentElement.mount('#payment-element');
            }
        });

        // Handle Stripe Payment Form Submission
        stripePaymentForm.addEventListener('submit', function (event) {
            event.preventDefault();

            stripe.confirmPayment({
                elements,
                confirmParams: {
                    return_url: '{{ route('invoice.confirm-payment') }}',
                },
            }).then(function (result) {
                if (result.error) {
                    alert(result.error.message);
                }
            });
        });

        // PayPal Integration
        paypalOption.addEventListener('change', function () {
            if (paypalOption.checked) {
                stripePaymentForm.style.display = 'none';
                paypalButtonContainer.style.display = 'block';

                paypal.Buttons({
                    createOrder: function (data, actions) {
                        return actions.order.create({
                            purchase_units: [{
                                amount: {
                                    value: '{{ $invoice->total_amount }}',
                                },
                                description: 'Invoice #{{ $invoice->invoice_number }}',
                            }],
                        });
                    },
                    onApprove: function (data, actions) {
                        return actions.order.capture().then(function (details) {
                            fetch('{{ route('invoice.confirm-payment') }}', {
                                method: 'POST',
                                headers: {
                                    'Content-Type': 'application/json',
                                    'X-CSRF-TOKEN': '{{ csrf_token() }}',
                                },
                                body: JSON.stringify({
                                    invoice_id: '{{ $invoice->id }}',
                                    payment_details: details,
                                }),
                            }).then(response => response.json())
                              .then(data => {
                                  if (data.success) {
                                      window.location.href = data.redirect_url;
                                  }
                              });
                        });
                    },
                }).render('#paypal-button-container');
            }
        });
    </script> --}}

@endsection