<?php

use Illuminate\Support\Facades\Route;
use App\Http\Middleware\AdminMiddleware;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\front\HomeController;

use App\Http\Controllers\front\UserController;
use App\Http\Controllers\admin\AdminController;
use App\Http\Controllers\admin\UsersController;
use App\Http\Controllers\front\InvoiceController;
use App\Http\Controllers\front\PaymentsController;
use App\Http\Controllers\admin\ContractsController;

// Route::get('/', function () {
//     return view('welcome');
// });

Route::get('/', [HomeController::class, 'index'])->name('/');
Route::get('/home', [HomeController::class, 'index'])->name('home');

Route::middleware('auth')->group(function () {

    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    Route::get('/dashboard', [UserController::class, 'dashboard'])->name('user.dashboard');
    Route::get('/contracts', [UserController::class, 'contracts'])->name('user.contracts.index');
    Route::get('/invoices', [InvoiceController::class, 'invoices'])->name('user.invoices.index');
    Route::get('/invoices/{id}', [InvoiceController::class, 'showInvoice'])->name('user.invoice.show');

    Route::get('invoice/payment/{id}', [PaymentsController::class, 'paymentPage'])->name('user.paymentPage');

});

Route::get('invoice/{id}/{token}', [InvoiceController::class, 'showPublic'])->name('invoice.show');
Route::get('invoice/download/{id}/{token}', [InvoiceController::class, 'download'])->name('invoice.download');
Route::get('invoice/payment-page', [InvoiceController::class, 'publicPaymentPage'])->name('invoice.publicPaymentPage');

Route::post('/process-stripe-payment', [PaymentsController::class, 'processStripePayment'])->name('processStripePayment');
Route::post('/handle-stripe-success', [PaymentsController::class, 'handleStripeSuccess'])->name('handleStripeSuccess');

Route::post('/create-paypal-order', [PaymentsController::class, 'createPaypalOrder'])->name('createPaypalOrder');
Route::post('/handle-paypal-success', [PaymentsController::class, 'handlePaypalSuccess'])->name('handlePaypalSuccess');

Route::get('/payment/return', [PaymentsController::class, 'paymentReturn'])->name('payment.return');

Route::get('/payment-done/{invoice}', [PaymentsController::class, 'paymentDone'])->name('paymentDone');


Route::get('complaints', [HomeController::class, 'complaints'])->name('user.complaints');
Route::get('faqs', [HomeController::class, 'faqs'])->name('faqs');
Route::get('contact-us', [HomeController::class, 'contact_us'])->name('contact-us');

Route::prefix('admin')->name('admin.')->group(function () {
    // Guest routes
    Route::middleware(['guest'])->group(function () {
        Route::get('/login', [AdminController::class, 'login'])->name('login');
        Route::post('/login', [AdminController::class, 'postLogin'])->name('login.post');
    });

    // Protected routes
    Route::middleware(AdminMiddleware::class)->group(function () {
        Route::get('/dashboard', [AdminController::class, 'dashboard'])->name('dashboard');
        Route::post('/logout', [AdminController::class, 'logout'])->name('logout');
        Route::get('/profile', [AdminController::class, 'profile'])->name('profile');

        Route::get('/cars', [AdminController::class, 'cars'])->name('cars');
        Route::get('/createCar', [AdminController::class, 'createCar'])->name('cars.create');

        Route::get('/users', [UsersController::class, 'users'])->name('users');

        Route::get('/getUsers', [UsersController::class, 'getUsers'])->name('getUsers');
        Route::get('/getAllUsers', [UsersController::class, 'getAllUsers'])->name('getAllUsers');
        Route::get('/getUser/{id}', [UsersController::class, 'getUser'])->name('getUser');
        Route::get('/createUser', [UsersController::class, 'createUser'])->name('users.create');
        Route::post('/storeUser', [UsersController::class, 'storeUser'])->name('users.store');
        Route::get('/editUser/{id}', [UsersController::class, 'editUser'])->name('user.edit');
        Route::post('/deleteUser/{id}', [UsersController::class, 'deleteUser'])->name('user.delete');

        Route::get('/contracts', [ContractsController::class, 'index'])->name('contracts');
        Route::get('/createContract', [ContractsController::class, 'createContract'])->name('contracts.create');
        Route::post('/storeContract', [ContractsController::class, 'storeContract'])->name('contracts.store');
        Route::get('/showContract/{id}', [ContractsController::class, 'showContract'])->name('contract.show');
        Route::get('/editContract/{id}', [ContractsController::class, 'editContract'])->name('contract.edit');
        Route::put('/updateContract/{id}', [ContractsController::class, 'updateContract'])->name('contract.update');
        Route::post('/deleteContract/{id}', [ContractsController::class, 'deleteContract'])->name('contract.delete');

        Route::get('/invoice/{invoiceNumber}', [ContractsController::class, 'showInvoice'])->name('invoice.show');
        Route::post('/invoice/{invoiceNumber}', [ContractsController::class, 'deleteInvoice'])->name('invoice.delete');
        Route::get('/send-invoice/{invoiceNumber}', [ContractsController::class, 'sendInvoice'])->name('invoice.send');
    });
});

require __DIR__.'/auth.php';
